/*
 
  Stratex PLL v.2 -  dual LMX2326
   YO4HFU 2021

  Registers LMX2326; F > R > N
  Register F header (C1,C2) = (1,1), Function Latch converted to Initialization;
  REF PD tested 100KHz...2MHz
  
  *********************************************
              Attiny 25/45/85
                 ___   ___
                |   |_|   |
        RST ****|         |**** Vcc
          3 ****|         |**** 2 (DATA)
(LE_0 TX) 4 ****|         |**** 1 (CLK)
        GND ****|         |**** 0 (LE_1 RX)
                |_________|
 
  **********************************************
 
 */

 ////////////////// TX REGISTERS ////////////////////////
  
  const unsigned long F_REG_0 = 0x93; // + PD
  const unsigned long R_REG_0 = 0x28; // 1MHz
  const unsigned long N_REG_0 = 0x102239; // 2250MHz

  
 ////////////////// RX REGISTERS ////////////////////////
 
  const unsigned long F_REG_1 = 0x93; // + PD
  const unsigned long R_REG_1 = 0x28; // 1MHz
  const unsigned long N_REG_1 = 0x102711; // 2500MHz

  
  int bp;
  int bx;
  unsigned long DTA_0;
  unsigned long DTA_1; 

  
 ///////////////// ATTINY PINOUT ////////////////////////
 
  const int LE_0 = 4;    // latch TX; pin 3
  const int LE_1 = 0;    // latch RX; pin 5
  const int DATA = 2;    // pin 7
  const int CLK = 1;     // pin 6
 
  
void setup() { 

  pinMode (LE_0, OUTPUT);    // latch TX
  pinMode (LE_1, OUTPUT);    // latch RX
  pinMode (CLK, OUTPUT);     // clock
  pinMode (DATA, OUTPUT);    // data     
  
  digitalWrite(LE_0,HIGH);   // clear LE line
  digitalWrite(LE_1,HIGH);   // clear LE line
  digitalWrite(CLK,LOW);     // clear CLK line
   

  {
 DTA_0 = F_REG_0; // first sent
 SendWord_0();
 DTA_0 = R_REG_0; 
 SendWord_0();
 DTA_0 = N_REG_0;
 SendWord_0();
 }  


 {
 DTA_1 = F_REG_1; // first sent
 SendWord_1();
 DTA_1 = R_REG_1; 
 SendWord_1();
 DTA_1 = N_REG_1;
 SendWord_1();
 }  
 
delay(200); // delay power ON 

}


void loop() { } // loop closed

 int SendWord_0() { 
 bp = 21;
  do { 
  bp = bp - 1; // loop through bit positions 21 to 0
  digitalWrite(CLK,LOW);
  digitalWrite(LE_0,LOW);
  digitalWrite(DATA, bitRead(DTA_0,bp) );
  digitalWrite(CLK,HIGH); 
  }
  while(bp>0); 
  digitalWrite(CLK,LOW); 
  digitalWrite(DATA,LOW);
  digitalWrite(LE_0,HIGH);   // Set TX LE to latch data
  delayMicroseconds (100);  // LE pulse
 }

 int SendWord_1() { 
 bx = 21;
  do { 
  bx = bx - 1; // loop through bit positions 21 to 0
  digitalWrite(CLK,LOW);
  digitalWrite(LE_1,LOW);
  digitalWrite(DATA, bitRead(DTA_1,bx) );
  digitalWrite(CLK,HIGH); 
  }
  while(bx>0); 
  digitalWrite(CLK,LOW); 
  digitalWrite(DATA,LOW);
  digitalWrite(LE_1,HIGH);   // Set RX LE to latch data
  delayMicroseconds (100);  // LE Pulse
 }
